@@ -266,6 +266,21 @@ static ComboConfigCandidate behavior_on_period[] =
     {NULL, NULL},
 };
 
+static ComboConfigCandidate behavior_on_focus_out[] =
+{
+    {N_("Commit"), "Commit"},
+    {N_("Clear"),  "Clear"},
+    {NULL, NULL},
+};
+
+#if 0
+static ComboConfigCandidate dict_encoding[] =
+{
+    {N_("EUC-JP"),    "EUC-JP"},
+    {N_("EUC-JP-MS"), "EUC-JP-MS"},
+    {NULL, NULL},
+};
+#endif
 
 static ComboConfigCandidate preedit_style[] =
 {
@@ -321,51 +336,6 @@ static void     on_color_button_changed           (ScimColorButton  *button,
                                                    gpointer          user_data);
 
 
-static BoolConfigData *
-find_bool_config_entry (const char *config_key)
-{
-    if (!config_key)
-        return NULL;
-
-    for (unsigned int i = 0; config_bool_common[i].key; i++) {
-        BoolConfigData *entry = &config_bool_common[i];
-        if (entry->key && !strcmp (entry->key, config_key))
-            return entry;
-    }
-
-    return NULL;
-}
-
-static IntConfigData *
-find_int_config_entry (const char *config_key)
-{
-    if (!config_key)
-        return NULL;
-
-    for (unsigned int i = 0; config_int_common[i].key; i++) {
-        IntConfigData *entry = &config_int_common[i];
-        if (entry->key && !strcmp (entry->key, config_key))
-            return entry;
-    }
-
-    return NULL;
-}
-
-static StringConfigData *
-find_string_config_entry (const char *config_key)
-{
-    if (!config_key)
-        return NULL;
-
-    for (unsigned int i = 0; config_string_common[i].key; i++) {
-        StringConfigData *entry = &config_string_common[i];
-        if (entry->key && !strcmp (entry->key, config_key))
-            return entry;
-    }
-
-    return NULL;
-}
-
 static StringConfigData *
 find_key_config_entry (const char *config_key)
 {
@@ -380,21 +350,6 @@ find_key_config_entry (const char *config_key)
     return NULL;
 }
 
-static ColorConfigData *
-find_color_config_entry (const char *config_key)
-{
-    if (!config_key)
-        return NULL;
-
-    for (unsigned int i = 0; config_color_common[i].fg_key; i++) {
-        ColorConfigData *entry = &config_color_common[i];
-        if (entry->fg_key && !strcmp (entry->fg_key, config_key))
-            return entry;
-    }
-
-    return NULL;
-}
-
 GtkWidget *
 create_check_button (const char *config_key)
 {
@@ -548,7 +503,8 @@ create_combo (const char *config_key, gpointer candidates_p,
     if (!__widget_tooltips)
         __widget_tooltips = gtk_tooltips_new();
     if (entry->tooltip)
-        gtk_tooltips_set_tip (__widget_tooltips, GTK_WIDGET (entry->widget),
+        gtk_tooltips_set_tip (__widget_tooltips,
+                              GTK_WIDGET (GTK_COMBO (entry->widget)->entry),
                               _(entry->tooltip), NULL);
 
     return GTK_WIDGET (entry->widget);
@@ -784,6 +740,11 @@ create_common_page (void)
                            (gpointer) &conversion_modes,
                            GTK_TABLE (table), 2);
 
+    /* behavior on focus out */
+    widget = create_combo (SCIM_ANTHY_CONFIG_BEHAVIOR_ON_FOCUS_OUT,
+                           (gpointer) &behavior_on_focus_out,
+                           GTK_TABLE (table), 3);
+
     return vbox;
 }
 
@@ -912,24 +873,24 @@ create_keyboard_page (void)
     column = gtk_tree_view_column_new_with_attributes (_("Feature"), cell,
                                                        "text", COLUMN_LABEL,
                                                        NULL);
-	gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
-	gtk_tree_view_column_set_fixed_width (column, 120);
-	gtk_tree_view_column_set_resizable(column, TRUE);
-	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
+    gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
+    gtk_tree_view_column_set_fixed_width (column, 120);
+    gtk_tree_view_column_set_resizable(column, TRUE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
 
     cell = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes (_("Key bindings"), cell,
                                                        "text", COLUMN_VALUE,
                                                        NULL);
-	gtk_tree_view_column_set_fixed_width (column, 200);
-	gtk_tree_view_column_set_resizable(column, TRUE);
-	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
+    gtk_tree_view_column_set_fixed_width (column, 200);
+    gtk_tree_view_column_set_resizable(column, TRUE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
 
     cell = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes (_("Description"), cell,
                                                        "text", COLUMN_DESC,
                                                        NULL);
-	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
 
     GtkTreeSelection *selection;
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
@@ -1079,17 +1040,24 @@ create_dict_page (void)
     GtkWidget *table, *button;
     StringConfigData *entry;
 
-    table = gtk_table_new (2, 3, FALSE);
+    table = gtk_table_new (3, 3, FALSE);
     gtk_widget_show (table);
 
+#if 0
+    // encoding of dictionary
+    create_combo (SCIM_ANTHY_CONFIG_DICT_ENCODING,
+                  (gpointer) &dict_encoding,
+                  GTK_TABLE (table), 0);
+#endif
+
     // dict admin command
     create_entry (SCIM_ANTHY_CONFIG_DICT_ADMIN_COMMAND,
-                  GTK_TABLE (table), 0);
+                  GTK_TABLE (table), 1);
     entry = find_string_config_entry (SCIM_ANTHY_CONFIG_DICT_ADMIN_COMMAND);
 
     button = gtk_button_new_with_mnemonic (_("_Launch"));
     gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (button),
-                      2, 3, 0, 1,
+                      2, 3, 1, 2,
                       (GtkAttachOptions) 0,
                       (GtkAttachOptions) 0, 4, 4);
     g_signal_connect (G_OBJECT (button), "clicked",
@@ -1098,12 +1066,12 @@ create_dict_page (void)
 
     // add word command
     create_entry (SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND,
-                  GTK_TABLE (table), 1);
+                  GTK_TABLE (table), 2);
     entry = find_string_config_entry (SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND);
 
     button = gtk_button_new_with_mnemonic (_("_Launch"));
     gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (button),
-                      2, 3, 1, 2,
+                      2, 3, 2, 3,
                       (GtkAttachOptions) 0,
                       (GtkAttachOptions) 0, 4, 4);
     g_signal_connect (G_OBJECT (button), "clicked",
@@ -1561,19 +1529,19 @@ setup_widget_value (void)
 static void
 load_style_files (const char *dirname)
 {
-	GDir *dir;
-	GError *error = NULL;
-	const gchar *entry;
+    GDir *dir;
+    GError *error = NULL;
+    const gchar *entry;
 
     // load system wide style files
-	dir = g_dir_open (dirname, 0, &error);
-	if (error)
-	{
-		//g_warning ("%s", error->message);
-		g_error_free (error);
-	}
+    dir = g_dir_open (dirname, 0, &error);
+    if (error)
+    {
+        //g_warning ("%s", error->message);
+        g_error_free (error);
+    }
 
-	if (dir) {
+    if (dir) {
         while ((entry = g_dir_read_name (dir)))
         {
             String file = dirname;
